#include <avr/io.h>
#include <avr/interrupt.h>

#define F_CPU 16000000L
#include <util/delay.h>

/*
 * Initializes input and output ports.
 */
void init_ports(void)
{	
	/* PORTA is used for input */
	DDRA = 0x00;
	PORTA = 0xFF;
	
	/* PORTD is used for output */
	DDRD = 0xFF;
	PORTD = 0x00;
	
	
	TCCR1A |= _BV(COM1A1) | _BV(COM1B1) | _BV(WGM11); //NON Inverted PWM
    TCCR1B |= _BV(WGM13) | _BV(WGM12) | _BV(CS12); /*| _BV(CS10);*/ //PRESCALER=64 MODE 14(FAST PWM)
	
	TCCR2A |= (1 << WGM20) | (1 << WGM21) | (1 << COM2B1) | (1 << COM2A1);
	TCCR2B |= (1 << WGM22) | (1 << CS22) | (1 << CS20);

}

int main(void)
{
	int i;
	int sensors_input;
	
	init_ports();

	/* enable interrupts */
	sei();
	
	/* PWM fill-rate set to 50% */
	
	while (1) {
		sensors_input = 0;
		
		/* acquire input from the sensors */
		for (i = 0; i < 8; i++)
			sensors_input |= (((1 << i) & PINA) >> i) << (7 - i);
	
		/* drive the motors based on the sensors input */
		
		OCR2A = 256 / 4;
		OCR2B = 256 / 4;
		
		OCR1A = 65535 / 2;
		OCR1B = 65535 / 2;
		
		if (PINA - sensors_input >= (1 << 4)) {
			
			PORTD = _BV(PD7);
			PORTD = _BV(PD3);
			
		}
		else if (sensors_input - PINA > (1 << 4)) {
			PORTD = _BV(PD6);
			
			PORTD = _BV(PD2);
		}
		else {
			PORTD = _BV(PD7) | _BV(PD6);
		}
    }


	return 0;
}